@@ -13,7 +13,7 @@ module RbConfig
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "9"
   CONFIG["TEENY"] = "1"
-  CONFIG["PATCHLEVEL"] = "0"
+  CONFIG["PATCHLEVEL"] = "194"
   CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
@@ -32,7 +32,7 @@ module RbConfig
   CONFIG["rubyhdrdir"] = "$(includedir)/$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--program-suffix=19' '--with-soname=ruby19' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["configure_args"] = " '--program-suffix=19' '--with-soname=ruby19' '--enable-pthread' '--enable-ipv6' '--disable-option-checking' '--with-tcl-include=/usr/local/include/tcl8.5' '--with-tk-include=/usr/local/include/tk8.5' '--with-X11-dir=/usr/X11R6' '--enable-shared' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXX=c++' 'CXXFLAGS=-O2 -pipe'"
   CONFIG["vendordir"] = "$(rubylibprefix)/vendor_ruby"
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["ruby_version"] = "1.9.1"
@@ -64,7 +64,7 @@ module RbConfig
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
   CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared $(CCDLFLAGS)"
   CONFIG["warnflags"] = "-Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Werror=pointer-arith -Werror=write-strings -Werror=declaration-after-statement -Werror=implicit-function-declaration"
-  CONFIG["debugflags"] = "-g"
+  CONFIG["debugflags"] = "-ggdb"
   CONFIG["optflags"] = "-O3"
   CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
   CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
@@ -104,7 +104,7 @@ module RbConfig
   CONFIG["RMDIR"] = "rmdir"
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
-  CONFIG["PKG_CONFIG"] = ""
+  CONFIG["PKG_CONFIG"] = "pkg-config"
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
@@ -139,21 +139,21 @@ module RbConfig
   CONFIG["LDFLAGS"] = "-L. -L/usr/local/lib -Wl,-E"
   CONFIG["CFLAGS"] = "-O2 -pipe -fPIC"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd5.1"
+  CONFIG["target_os"] = "openbsd5.2"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "mips64el"
-  CONFIG["target"] = "mips64el-unknown-openbsd5.1"
-  CONFIG["host_os"] = "openbsd5.1"
+  CONFIG["target"] = "mips64el-unknown-openbsd5.2"
+  CONFIG["host_os"] = "openbsd5.2"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "mips64el"
-  CONFIG["host"] = "mips64el-unknown-openbsd5.1"
+  CONFIG["host"] = "mips64el-unknown-openbsd5.2"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd5.1"
+  CONFIG["build_os"] = "openbsd5.2"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "mips64el"
-  CONFIG["build"] = "mips64el-unknown-openbsd5.1"
-  CONFIG["RUBY_RELEASE_DATE"] = "2011-10-30"
+  CONFIG["build"] = "mips64el-unknown-openbsd5.2"
+  CONFIG["RUBY_RELEASE_DATE"] = "2012-04-20"
   CONFIG["RUBY_PROGRAM_VERSION"] = "1.9.3"
   CONFIG["BASERUBY"] = "echo executable host ruby is required.  use --with-baseruby option.; false"
   CONFIG["target_alias"] = ""
@@ -175,7 +175,7 @@ module RbConfig
   CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
   CONFIG["oldincludedir"] = "/usr/include"
   CONFIG["includedir"] = "$(prefix)/include"
-  CONFIG["localstatedir"] = "$(prefix)/var"
+  CONFIG["localstatedir"] = "$(DESTDIR)/var"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
   CONFIG["sysconfdir"] = "$(DESTDIR)/etc"
   CONFIG["datadir"] = "$(datarootdir)"
